==> waafipay_sdk-0.0.1.tar.gz: lib/waafipay_sdk.dart <==
library waafipay_sdk;
import 'dart:convert';
import 'dart:io';


import 'package:http/http.dart' as http;

/// A WaafiPay.
class Waafipay {

  Future<String> apiRequest(String url, String merchantUid, String apiUserId, String apiKey, String number, String amount) async {
    HttpClient httpClient = new HttpClient();
    Map jsonMap = {
      'schemaVersion': "1.0",
      'requestId': "7399533922",
      'timestamp': "2021-10-13 Africa",
      'channelName': "WEB",
      'serviceName': "API_PREAUTHORIZE",
      'serviceParams': {
        'merchantUid': merchantUid,
        'apiUserId': apiUserId,
        'apiKey': apiKey,
        'paymentMethod': "MWALLET_ACCOUNT",
        'payerInfo': {
          'accountNo': number
        },
        'transactionInfo': {
          'referenceId': "11111",
          'invoiceId': "22222",
          'amount': amount,
          'currency': "USD",
          'description': "WaafiPay Sdk PreAuth"
        }
      }
    };
    HttpClientRequest request = await httpClient.postUrl(Uri.parse(url));
    request.headers.set('content-type', 'application/json');
    request.add(utf8.encode(json.encode(jsonMap)));
    HttpClientResponse response = await request.close();
    String reply = await response.transform(utf8.decoder).join();
    Map mapJson = json.decode(reply);
    Map jsonMaps = {
      'schemaVersion': "1.0",
      'requestId': "7399533922",
      'timestamp': "2021-10-13 Africa",
      'channelName': "WEB",
      'serviceName': "API_PREAUTHORIZE_COMMIT",
      'serviceParams': {
        'merchantUid': merchantUid,
        'apiUserId': apiUserId,
        'apiKey': apiKey,
        'transactionId': mapJson['params']['transactionId'],
        'description': "WaafiPay Sdk Commit",
        'referenceId': "11111"
      }
    };
    HttpClientRequest requests = await httpClient.postUrl(Uri.parse(url));
    requests.headers.set('content-type', 'application/json');
    requests.add(utf8.encode(json.encode(jsonMaps)));
    HttpClientResponse responses = await requests.close();
    String replys = await responses.transform(utf8.decoder).join();
    httpClient.close();
    return replys;
  }
}

==> waafipay_sdk-0.0.3.tar.gz: lib/waafipay_sdk.dart <==
library waafipay_sdk;
import 'dart:convert';
import 'dart:io';


// import 'package:http/http.dart' as http;

class Waafipay {

  Future<String> paidToWaafiPay(String url, String merchantUid, String apiUserId, String apiKey, String number, String amount) async {
    HttpClient httpClient = new HttpClient();
    Map jsonMap = {
      'schemaVersion': "1.0",
      'requestId': "7399533922",
      'timestamp': "2021-10-13 Africa",
      'channelName': "WEB",
      'serviceName': "API_PREAUTHORIZE",
      'serviceParams': {
        'merchantUid': merchantUid,
        'apiUserId': apiUserId,
        'apiKey': apiKey,
        'paymentMethod': "MWALLET_ACCOUNT",
        'payerInfo': {
          'accountNo': number
        },
        'transactionInfo': {
          'referenceId': "11111",
          'invoiceId': "22222",
          'amount': amount,
          'currency': "USD",
          'description': "WaafiPay Sdk PreAuth"
        }
      }
    };
    HttpClientRequest request = await httpClient.postUrl(Uri.parse(url));
    request.headers.set('content-type', 'application/json');
    request.add(utf8.encode(json.encode(jsonMap)));
    HttpClientResponse response = await request.close();
    String reply = await response.transform(utf8.decoder).join();
    Map mapJson = json.decode(reply);
    Map jsonMaps = {
      'schemaVersion': "1.0",
      'requestId': "7399533922",
      'timestamp': "2021-10-13 Africa",
      'channelName': "WEB",
      'serviceName': "API_PREAUTHORIZE_COMMIT",
      'serviceParams': {
        'merchantUid': merchantUid,
        'apiUserId': apiUserId,
        'apiKey': apiKey,
        'transactionId': mapJson['params']['transactionId'],
        'description': "WaafiPay Sdk Commit",
        'referenceId': "11111"
      }
    };
    HttpClientRequest requests = await httpClient.postUrl(Uri.parse(url));
    requests.headers.set('content-type', 'application/json');
    requests.add(utf8.encode(json.encode(jsonMaps)));
    HttpClientResponse responses = await requests.close();
    String replys = await responses.transform(utf8.decoder).join();
    httpClient.close();
    return replys;
  }
}
